@@ -1,7 +1,5 @@
 /*
-   $Id: Pg.h 12599 2009-03-10 23:28:35Z turnstep $
-
-   Copyright (c) 2000-2009 Greg Sabino Mullane and others: see the Changes file
+   Copyright (c) 2000-2012 Greg Sabino Mullane and others: see the Changes file
    Copyright (c) 1997-2000 Edmund Mergl
    Portions Copyright (c) 1994-1997 Tim Bunce
 
@@ -44,6 +42,10 @@ static int errno;
 #define INV_WRITE 0x00020000
 #endif
 
+#ifndef PGRES_COPY_BOTH
+#define PGRES_COPY_BOTH 8
+#endif
+
 #ifdef BUFSIZ
 #undef BUFSIZ
 #endif
